@@ -40,6 +40,8 @@ def string_regex(keywords, path):
     """Returns a string with the regular expression containing all combinations
     of the keywords."""
     keywords = keywords.split()
+    if len(keywords) == 0:
+        return ''
     if len(keywords) == 1:
         return keywords[0]
     regex = ""
@@ -215,10 +217,10 @@ class CatfishSearchMethod_Walk(CatfishSearchMethod):
             if not self.running:
                 break
             for folder in dirs:
-                if any(keyword in folder for keyword in keywords):
+                if any(keyword.lower() in folder.lower() for keyword in keywords):
                     yield os.path.join(root, folder)
             for filename in files:
-                if any(keyword in filename for keyword in keywords):
+                if any(keyword.lower() in filename.lower() for keyword in keywords):
                     yield os.path.join(root, filename)
             yield True
         yield False
